#ifndef __MAIN_HAL_H
#define __MAIN_HAL_H

#include "main.h"
#include "stm32g4xx_hal.h"
#include "adc.h"
#include "tim.h"
#include "fdcan.h"
#include "i2c.h"

#define VERSION 0x0001

#define INPUT_RANGE_10_VOLTS 0
#define INPUT_RANGE_30_VOLTS 1

#define IN1_ANALOG ADC_CHANNEL_12
#define IN2_ANALOG ADC_CHANNEL_14
#define IN3_ANALOG ADC_CHANNEL_1
#define IN4_DIGITAL 4
#define IN5_DIGITAL 5

#define OUT1_HS 1
#define OUT2_HS 2
#define OUT3_HS 3
#define OUT4_HS 4
#define OUT5_LS 5

/**
 * @brief  GPIO Bit SET and Bit RESET enumeration
 */
typedef enum
{
  OUT_OFF = 0U,
  OUT_ON
} GPIO_PinState_OUT;

#define EEPROM_ADDRESS          0xA0
#define EEPROM_BUFFER_SIZE      32  // Page size
#define EEPROM_WRITE_TIME       5   // Page write time in ms
#define EEPROM_TIMEOUT          10  // timeout for write

void Additional_Init ( void );
void Additional_ADC_Init ( void );
void Additional_TIM5_Init ( void );
void Additional_TIM6_Init ( void );
void Additional_TIM8_Init ( void );
void Additional_CAN_Init ( void );

void SendCAN_ClassicMessage ( uint32_t CANID, uint32_t DLC, uint8_t Byte0, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4, uint8_t Byte5,
    uint8_t Byte6, uint8_t Byte7 );
void SendCAN_FDMessage_DLC12 ( uint32_t CANID, uint8_t Byte0, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4, uint8_t Byte5, uint8_t Byte6,
    uint8_t Byte7, uint8_t Byte8, uint8_t Byte9, uint8_t Byte10, uint8_t Byte11 );

uint16_t ReadInputAnalog_mV ( uint32_t Channel, uint8_t MeasureingRange );
uint8_t ReadInputDigital ( uint8_t Channel );
void WriteDigitalOutput ( uint8_t Channel, uint8_t State );
void WriteDigitalOutputPWM_Percent ( uint8_t Channel, uint16_t DutyCycle_Percent );
void WriteLED_Percent ( uint16_t DutyCycle_Percent );

uint8_t EEPROM_Read_Byte ( uint16_t BaseAddress );
void EEPROM_Write_Byte ( uint16_t BaseAddress, uint8_t Data );

#endif /* __MAIN_HAL_H */
